# codelinescounter
Python library for counting lines of python code in file or directory

# Установка
## Через Pip
```bash
  $ pip install codelinescounter
```
## Вручную
```bash
  $ git clone https://github.com/AndK17/codelinescounter
  $ cd codelinescounter
  $ python setup.py install
```
# Использование
```bash
$ python -m clc {path to file or directory}
```